@@ -1,9 +1,7 @@
 import datetime
-import mimetypes
 import urllib.request
 import uuid
 import zipfile
-from enum import Enum
 from typing import List
 
 import requests
@@ -395,3 +393,30 @@ class SDK:
         }
         response = requests.request("POST", url, headers=headers, json=payload)
         return response.json()
+
+
+    def create_user(self, user: dict):
+        url = "%s/v2/createUser" % self.host
+        headers = {
+            'apikey': self.api_key
+        }
+        payload = user
+        response = requests.request("POST", url, headers=headers, json=payload)
+        return response.json()
+    def submit_labeltask(self, task_id: str, annotations: dict):
+        url = "%s/v2/submitTask/%s" % (self.host, task_id)
+        headers = {
+            'apikey': self.api_key
+        }
+        payload = annotations
+        response = requests.request("POST", url, headers=headers, json=payload)
+        return response.json()
+
+    def get_next_labeltask(self, project_id: str):
+        url = "%s/v2/getNextTask/%s" % (self.host, project_id)
+        headers = {
+            'apikey': self.api_key
+        }
+
+        response = requests.request("GET", url, headers=headers)
+        return response.json()
\ No newline at end of file
